home | help
UUENCODE(1)		     General Commands Manual		     UUENCODE(1)

NAME
     uuencode, uudecode, b64encode, b64decode -- encode/decode a binary file

SYNOPSIS
     uuencode [-m] [-o output_file] [file] name
     uudecode [-cimprs] [file ...]
     uudecode [-i] -o output_file
     b64encode [-o output_file] [file] name
     b64decode [-cimprs] [file ...]
     b64decode [-i] -o output_file [file]

DESCRIPTION
     The  uuencode and uudecode utilities are used to transmit binary files over
     transmission mediums that do not support other than simple ASCII data.  The
     b64encode utility is synonymous with uuencode with the -m	flag  specified.
     The  b64decode  utility is synonymous with uudecode with the -m flag speci-
     fied.

     The uuencode utility reads file (or by  default  the  standard  input)  and
     writes an encoded version to the standard output, or output_file if one has
     been  specified.	The encoding uses only printing ASCII characters and in-
     cludes the mode of the file and the operand name for use by uudecode.

     The uudecode utility transforms uuencoded files (or by default,  the  stan-
     dard  input)  into  the  original form.  The resulting file is named either
     name or (depending on options passed to uudecode) output_file and will have
     the mode of the original file except that setuid and execute bits	are  not
     retained.	The uudecode utility ignores any leading and trailing lines.

     The following options are available for uuencode:

     -m     Use  the  Base64  method  of  encoding,  rather than the traditional
	    uuencode algorithm.

     -o output_file
	    Output to output_file instead of standard output.

     The following options are available for uudecode:

     -c     Decode more than one uuencoded file from file if possible.

     -i     Do not overwrite files.

     -m     When used with the -r flag, decode Base64 input  instead  of  tradi-
	    tional uuencode input.  Without -r it has no effect.

     -o output_file
	    Output to output_file instead of any pathname contained in the input
	    data.

     -p     Decode file and write output to standard output.

     -r     Decode  raw (or broken) input, which is missing the initial and pos-
	    sibly the final framing lines.  The input is assumed to  be  in  the
	    traditional uuencode encoding, but if the -m flag is used, or if the
	    utility  is invoked as b64decode, then the input is assumed to be in
	    Base64 format.

     -s     Do not strip output pathname to base filename.  By default	uudecode
	    deletes  any prefix ending with the last slash '/' for security rea-
	    sons.

EXAMPLES
     The following example packages up a source tree, compresses  it,  uuencodes
     it  and  mails it to a user on another system.  When uudecode is run on the
     target system, the file ``src_tree.tar.Z'' will be created which  may  then
     be uncompressed and extracted into the original tree.

	   tar cf - src_tree | compress |
	   uuencode src_tree.tar.Z | mail sys1!sys2!user

     The  following  example  unpacks all uuencoded files from your mailbox into
     your current working directory.

	   uudecode -c < $MAIL

     The following example extracts a compressed tar archive from your mailbox

	   uudecode -o /dev/stdout < $MAIL | zcat | tar xfv -

SEE ALSO
     basename(1), compress(1), mail(1), uucp(1), uuencode(5)

BUGS
     Files encoded using the traditional algorithm are expanded by 35% (3  bytes
     become 4 plus control information).

HISTORY
     The uudecode and uuencode utilities appeared in 4.0BSD.

FreeBSD 4.9			January 27, 2002		     UUENCODE(1)

home | help